From 055e7cde6466fbd1e27881e8527eb23e48f72c71 Mon Sep 17 00:00:00 2001
From: Akash Mehrotra <mehrotra.akash@gmail.com>
Date: Sun, 7 Aug 2011 23:49:01 +0530
Subject: [PATCH 07/13] LUA: Enable/Disable EQ, fix EQ input validation

---
 modules/lua/libs/equalizer.c          |   23 +++++++++++++++++++++--
 share/lua/http/requests/README.txt    |    4 ++++
 share/lua/http/requests/equalizer.xml |    4 ++++
 3 files changed, 29 insertions(+), 2 deletions(-)

diff --git a/modules/lua/libs/equalizer.c b/modules/lua/libs/equalizer.c
index a55e3e9..dfa269b 100644
--- a/modules/lua/libs/equalizer.c
+++ b/modules/lua/libs/equalizer.c
@@ -34,6 +34,7 @@
 
 #include <vlc_common.h>
 #include <vlc_aout.h>
+#include <vlc_aout_intf.h>
 #include <vlc_input.h>
 #include <vlc_charset.h>
 
@@ -42,6 +43,8 @@
 
 #include "input.h"
 #include "../libs.h"
+#include "../vlc.h"
+#include "playlist.h"
 
 #if !defined WIN32
 # include <locale.h>
@@ -132,6 +135,9 @@ Band 9: 16 kHz
 *****************************************************************************/
 static int vlclua_equalizer_get( lua_State *L )
 {
+    int bandid = luaL_checknumber( L, 1 );
+    if ( bandid < 0 || bandid > 9)
+        return 0;
     input_thread_t *p_input = vlclua_get_input_internal( L );
     if( !p_input )
         return 0;
@@ -151,7 +157,6 @@ static int vlclua_equalizer_get( lua_State *L )
     }
     free( psz_af );
 
-    int bandid = luaL_checknumber( L, 1 );
     char *psz_bands_origin, *psz_bands;
     psz_bands_origin = psz_bands = var_GetNonEmptyString( p_aout, "equalizer-bands" );
     locale_t loc = newlocale (LC_NUMERIC_MASK, "C", NULL);
@@ -184,6 +189,9 @@ static int vlclua_equalizer_get( lua_State *L )
 *****************************************************************************/
 static int vlclua_equalizer_set( lua_State *L )
 {
+    int bandid = luaL_checknumber( L, 1 );
+    if ( bandid < 0 || bandid > 9)
+        return 0;
     input_thread_t *p_input = vlclua_get_input_internal( L );
     if( !p_input )
         return 0;
@@ -203,7 +211,6 @@ static int vlclua_equalizer_set( lua_State *L )
     }
     free( psz_af );
 
-    int bandid = luaL_checknumber( L, 1 );
     float level = luaL_checknumber( L, 2 );
     char *bands = var_GetString( p_aout, "equalizer-bands" );
     char newstr[7];
@@ -227,12 +234,24 @@ static int vlclua_equalizer_set( lua_State *L )
     return 1;
 }
 
+/****************************************************************************
+* Enable/disable Equalizer
+*****************************************************************************/
+static int vlclua_equalizer_enable ( lua_State *L )
+{
+    playlist_t *p_playlist = vlclua_get_playlist_internal( L );
+    bool state = luaL_checkboolean ( L , 1 );
+    aout_EnableFilter( p_playlist, "equalizer", state );
+    return 0;
+}
+
 
 static const luaL_Reg vlclua_equalizer_reg[] = {
     { "preampget", vlclua_preamp_get },
     { "preampset", vlclua_preamp_set },
     { "equalizerget", vlclua_equalizer_get },
     { "equalizerset", vlclua_equalizer_set },
+    { "enable", vlclua_equalizer_enable },
     { NULL, NULL }
 };
 
diff --git a/share/lua/http/requests/README.txt b/share/lua/http/requests/README.txt
index b9b2ae7..4a580a5 100644
--- a/share/lua/http/requests/README.txt
+++ b/share/lua/http/requests/README.txt
@@ -138,6 +138,10 @@ equalizer.xml:
 
 >command=equalizer&band=<band>&val=<gain in dB, must be >=-20 and <=20)
 
+>command=enable&val=<0 or 1>
+ 0 --  disables the equalizer
+ 1 --  enables the equalizer
+
 <Displays the equalizer band gains.
 Band 0: 60 Hz, 1: 170 Hz, 2: 310 Hz, 3: 600 Hz, 4: 1 kHz,
 5: 3 kHz, 6: 6 kHz, 7: 12 kHz , 8: 14 kHz , 9: 16 kHz
diff --git a/share/lua/http/requests/equalizer.xml b/share/lua/http/requests/equalizer.xml
index 9a812c7..62e689c 100644
--- a/share/lua/http/requests/equalizer.xml
+++ b/share/lua/http/requests/equalizer.xml
@@ -34,6 +34,10 @@ if what then return math.floor(what*math.pow(10,precision)+0.5) / math.pow(10,pr
 end
 if command == "preamp" then vlc.equalizer.preampset(val)
 elseif command == "equalizer" then vlc.equalizer.equalizerset(band,val)
+elseif command == "enable" then
+  if val == '0' then vlc.equalizer.enable(false) 
+  elseif val == '1' then vlc.equalizer.enable(true)
+  end
 end
 freq = { 60 , 170 , 310 , 600 , 1000 , 3000 , 6000 , 12000 , 14000 , 16000 }
 ?>
-- 
1.7.4.1

